@@ -7,14 +7,14 @@ from typing import Optional, Union
 
 from torch import Tensor
 
-from aac_metrics.classes.base import Metric
+from aac_metrics.classes.base import AACMetric
 from aac_metrics.functional.spider import spider
 
 
 logger = logging.getLogger(__name__)
 
 
-class SPIDEr(Metric):
+class SPIDEr(AACMetric):
     """SPIDEr class.
 
     Paper: https://arxiv.org/pdf/1612.00370.pdf
@@ -36,7 +36,7 @@ class SPIDEr(Metric):
         n: int = 4,
         sigma: float = 6.0,
         # SPICE args
-        cache_path: str = "$HOME/aac-metrics-cache",
+        cache_path: str = "$HOME/.cache",
         java_path: str = "java",
         tmp_path: str = "/tmp",
         n_threads: Optional[int] = None,
